# pyportall

Python SDK to Portall's data and services.

Please take a look at the [documentation](https://inspide.github.io/pyportall/) to get set up.

## Version compatibility

* pyportall versions 0.X.Y are compatible with Portall's API v0 only
* pyportall versions 1.X are compatible with Portall's API v1 only
